#ifndef NT2_INCLUDE_FUNCTIONS_DIVROUND_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIVROUND_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/divround.hpp>

#endif
